summaryrefslogtreecommitdiffstats
path: root/config-db/devel-tools
diff options
context:
space:
mode:
Diffstat (limited to 'config-db/devel-tools')
-rwxr-xr-xconfig-db/devel-tools/create-simple-db.pl5
-rwxr-xr-xconfig-db/devel-tools/extractTranslations.pl2
-rwxr-xr-xconfig-db/devel-tools/test-config-db.pl6
-rwxr-xr-xconfig-db/devel-tools/test-config-demuxer.pl6
4 files changed, 11 insertions, 8 deletions
diff --git a/config-db/devel-tools/create-simple-db.pl b/config-db/devel-tools/create-simple-db.pl
index 1fd8f242..efb7d7ab 100755
--- a/config-db/devel-tools/create-simple-db.pl
+++ b/config-db/devel-tools/create-simple-db.pl
@@ -20,11 +20,12 @@ create-simple-db.pl
use Getopt::Long qw(:config pass_through);
use Pod::Usage;
-# add the lib-folder and the folder this script lives in to perl's search
+# add the lib-folder and the config-db folder to perl's search
# path for modules:
use FindBin;
+use lib "$FindBin::RealBin/../../lib";
use lib "$FindBin::RealBin/..";
- # development path
+ # development path to config-db stuff
use OpenSLX::Basics;
use OpenSLX::ConfigDB qw(:access :manipulation);
diff --git a/config-db/devel-tools/extractTranslations.pl b/config-db/devel-tools/extractTranslations.pl
index 3907a184..223fb050 100755
--- a/config-db/devel-tools/extractTranslations.pl
+++ b/config-db/devel-tools/extractTranslations.pl
@@ -24,8 +24,6 @@ use File::Find;
use Getopt::Long;
use Pod::Usage;
-use Text::ParseWords;
-
my (
$helpReq,
$show,
diff --git a/config-db/devel-tools/test-config-db.pl b/config-db/devel-tools/test-config-db.pl
index aa6267bd..0d196130 100755
--- a/config-db/devel-tools/test-config-db.pl
+++ b/config-db/devel-tools/test-config-db.pl
@@ -8,10 +8,12 @@
#
use strict;
# add the folder this script lives in to perl's search path for modules:
use FindBin;
+use lib "$FindBin::RealBin/../../lib";
use lib "$FindBin::RealBin/..";
- # development path only (as script should never be installed)
+ # development path to config-db stuff
use OpenSLX::Basics;
use OpenSLX::ConfigDB qw(:access :manipulation);
@@ -8,10 +8,12 @@
#
use strict;
-# add the folder this script lives in to perl's search path for modules:
+# add the lib-folder and the config-db folder to perl's search
+# path for modules:
use FindBin;
diff --git a/config-db/devel-tools/test-config-demuxer.pl b/config-db/devel-tools/test-config-demuxer.pl
index 82003f18..43447dd9 100755
--- a/config-db/devel-tools/test-config-demuxer.pl
+++ b/config-db/devel-tools/test-config-demuxer.pl
@@ -8,10 +8,12 @@
#
use strict;
# add the folder this script lives in to perl's search path for modules:
use FindBin;
+use lib "$FindBin::RealBin/../../lib";
use lib "$FindBin::RealBin/..";
- # development path only (as script should never be installed)
+ # development path to config-db stuff
use OpenSLX::Basics;
use OpenSLX::ConfigDB qw(:access :manipulation);
@@ -8,10 +8,12 @@
#
use strict;
-# add the folder this script lives in to perl's search path for modules:
+# add the lib-folder and the config-db folder to perl's search
+# path for modules:
use FindBin;